@@ -1,12 +1,12 @@
 # Easy.pm - Easy to Use DBI interface
 
 # Copyright (C) 1999,2000,2001,2002 Stefan Hornburg, Dennis Schn
-# Copyright (C) 2003,2004,2005,2006 Stefan Hornburg (Racke) <racke@linuxia.de>
+# Copyright (C) 2003,2004,2005,2006,2007,2008 Stefan Hornburg (Racke) <racke@linuxia.de>
 
 # Authors: Stefan Hornburg (Racke) <racke@linuxia.de>
 #          Dennis Schn <ds@1d10t.de>
 # Maintainer: Stefan Hornburg (Racke) <racke@linuxia.de>
-# Version: 0.17
+# Version: 0.18
 
 # This file is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -38,7 +38,7 @@ require Exporter;
 
 # Public variables
 use vars qw($cache_structs);
-$VERSION = '0.17';
+$VERSION = '0.18';
 $cache_structs = 1;
 
 use DBI;
@@ -575,6 +575,47 @@ sub delete {
 	$sth -> rows();
 }
 
+# ----------------------------------------
+# METHOD: do_without_transaction STATEMENT
+# ----------------------------------------
+
+=over 4
+
+=item do_without_transaction I<statement>
+
+  $sth = $dbi_interface -> do_without_transaction ("CREATE DATABASE foo");
+
+  Issues a DBI do statement while forcing autocommit. This is used for
+  statements that can't be run in transaction mode (like CREATE DATABASE
+  in PostgreSQL).
+
+=back
+
+=cut
+
+sub do_without_transaction {
+	my ($self, $statement) = @_;
+	my ($rv, $autocommit);
+
+	return unless $self -> connect ();
+
+	$autocommit = $self -> {CONN} -> {AutoCommit};
+
+    # Force autocommit
+    $self -> {CONN} -> {AutoCommit} = 1;
+
+    $rv = $self -> {CONN} -> do ($statement);
+	
+    # Restore autocommit setting
+    $self -> {CONN} -> {AutoCommit} = $autocommit;
+
+    unless (defined $rv) {
+		$self -> fatal ("Couldn't do statement \"$statement\"");
+	}
+
+	return $rv;
+}
+
 # -------------------------------
 # METHOD: rows TABLE [CONDITIONS]
 # -------------------------------
@@ -1313,6 +1354,10 @@ sub is_auth_error {
 			return 1;
 		}
 	} elsif ($self->{DRIVER} eq 'Pg') {
+		if ($msg =~ /^DBI\sconnect(\('dbname=.*?(;host=.*?)?',.*?\))? failed:.+no password supplied/) {
+			return 1;
+		}
+    
 		if ($msg =~ /^DBI->connect failed.+no password supplied/) {
 			return 1;
 		}
@@ -1479,7 +1524,7 @@ David B. Bitton <david@codenoevil.com>.
 
 =head1 VERSION
 
-0.17
+0.18
 
 =head1 SEE ALSO
 
